Tree

Type Alias Tree 

pub type Tree = [i8];
A tree specification: an array of i8 branch entries (RFC 6386 8.1).

Each even index is an interior node; entry i and i + 1 are its 0 (left) and 1 (right) branches. A positive entry is the index of a deeper interior node; a non-positive entry v is a leaf whose value is -v. The associated interior-node probabilities are indexed by i >> 1.